==> haskell-here-1.2.14-128-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-here.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 here
version:              1.2.14
visibility:           public
id:                   here-1.2.14-14elL5A05j28LXcX3RGvfa
key:                  here-1.2.14-14elL5A05j28LXcX3RGvfa
license:              BSD-3-Clause
copyright:            ©2013 Taylor M. Hedberg, ©2014 Google Inc.
maintainer:           t@tmh.cc
author:               Taylor M. Hedberg
homepage:             https://github.com/tmhedberg/here
synopsis:             Here docs & interpolated strings via quasiquotation
description:          Here docs & interpolated strings via quasiquotation
category:             Data
abi:                  a6f8921fab6dc3504747997057bc4bca
exposed:              True
exposed-modules:
    Data.String.Here Data.String.Here.Interpolated
    Data.String.Here.Uninterpolated

hidden-modules:       Data.String.Here.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/here-1.2.14
library-dirs:         /usr/lib/ghc-9.6.6/site-local/here-1.2.14
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/here-1.2.14
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-here
hs-libraries:         HShere-1.2.14-14elL5A05j28LXcX3RGvfa
depends:
    base-4.18.2.1 haskell-src-meta-0.8.15-LBcHkcwhTm5LXkELzKR9cO
    mtl-2.3.1 parsec-3.1.16.1 template-haskell-2.20.0.0

haddock-interfaces:   /usr/share/doc/haskell-here/html/here.haddock
haddock-html:         /usr/share/doc/haskell-here/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-here-1.2.14-129-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-here.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 here
version:              1.2.14
visibility:           public
id:                   here-1.2.14-B8m6CfWx6gwJzac2I79Mu8
key:                  here-1.2.14-B8m6CfWx6gwJzac2I79Mu8
license:              BSD-3-Clause
copyright:            ©2013 Taylor M. Hedberg, ©2014 Google Inc.
maintainer:           t@tmh.cc
author:               Taylor M. Hedberg
homepage:             https://github.com/tmhedberg/here
synopsis:             Here docs & interpolated strings via quasiquotation
description:          Here docs & interpolated strings via quasiquotation
category:             Data
abi:                  86ca300bdbeded8d018db556aa5abead
exposed:              True
exposed-modules:
    Data.String.Here Data.String.Here.Interpolated
    Data.String.Here.Uninterpolated

hidden-modules:       Data.String.Here.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/here-1.2.14
library-dirs:         /usr/lib/ghc-9.6.6/site-local/here-1.2.14
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/here-1.2.14
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-here
hs-libraries:         HShere-1.2.14-B8m6CfWx6gwJzac2I79Mu8
depends:
    base-4.18.2.1 haskell-src-meta-0.8.15-JRAB7pIAVBCFkIUunJRyzc
    mtl-2.3.1 parsec-3.1.16.1 template-haskell-2.20.0.0

haddock-interfaces:   /usr/share/doc/haskell-here/html/here.haddock
haddock-html:         /usr/share/doc/haskell-here/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
